@@ -1,8 +1,8 @@
 #include "Python.h"
 #include "kmerslib.h"
-
+#include <string.h>
 static PyObject* kmerslib_core_makeFFPS(PyObject *self, PyObject *args){
-	char *dir;
+	std::string dir;
     int startk;
     int endk;
     int ndevice;
